#[non_exhaustive]pub enum EventError {
ZeroVersion,
EventTypeMismatch,
MissingTarget,
PayloadIdentityMismatch,
TerminalStatusMismatch,
InvalidTerminalResult,
InvalidPlanFingerprint,
InvalidParametersDigest,
}Expand description
Invalid lifecycle event envelope.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ZeroVersion
Event schema versions are one-based.
EventTypeMismatch
The stored event type does not match its tagged payload.
MissingTarget
A lifecycle stage that requires a resolved target omitted it.
PayloadIdentityMismatch
Payload operation identity, name, or target differs from the envelope.
TerminalStatusMismatch
Terminal payload status differs from the event type.
InvalidTerminalResult
The terminal result violates result invariants.
InvalidPlanFingerprint
The embedded plan fingerprint is invalid.
InvalidParametersDigest
Requested parameter digest is not lowercase SHA-256.