#[non_exhaustive]pub enum MutationSendState {
NotSent,
Sent,
Unknown,
NotApplicable,
}Expand description
Whether a failed operation may already have reached the target.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotSent
No mutation request was sent.
Sent
The mutation request was sent.
Unknown
The transport cannot determine whether the mutation was sent.
NotApplicable
The operation was read-only.