SpecError

Enum SpecError 

#[non_exhaustive]
pub enum SpecError { ZeroSchemaVersion, SchemaIdentityMismatch, InvalidParameter(String), DuplicateParameter(String), EmptyAlternative, DuplicateAlternative, DestructiveRead, ReadMarkedIdempotent, UnsafeRetryClaim, RiskyMutationWithoutPlan, InvalidRequirement(String), }
Invalid operation catalog metadata.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ZeroSchemaVersion

Schema version zero is invalid.



SchemaIdentityMismatch

Parameter or result schema identity did not match the operation and version.



InvalidParameter(String)

A parameter name is invalid.



DuplicateParameter(String)

A parameter appears more than once in a group.



EmptyAlternative

An alternative parameter group is empty.



DuplicateAlternative

The same alternative parameter group appears more than once.



DestructiveRead

A read operation was incorrectly classified as destructive.



ReadMarkedIdempotent

Read operations do not use mutation idempotency metadata.



UnsafeRetryClaim

A non-idempotent mutation claimed safe automatic retry.



RiskyMutationWithoutPlan

A destructive or privileged mutation omitted planning support.



InvalidRequirement(String)

An implementation capability requirement is invalid.