#[non_exhaustive]pub enum TargetKind {
Show 17 variants
Host,
DockerDaemon,
Container,
ComposeProject,
IncusServer,
IncusInstance,
Image,
Network,
StoragePool,
StorageVolume,
File,
Process,
LogSource,
ZfsPool,
ZfsDataset,
ZfsSnapshot,
Custom(OperationName),
}Expand description
Typed category of a resource targeted by an operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Host
A physical or virtual host.
DockerDaemon
A Docker-compatible daemon.
Container
A Docker or OCI container.
ComposeProject
A Compose project.
IncusServer
An Incus daemon.
IncusInstance
An Incus container or virtual machine.
Image
A container or Incus image.
Network
A network resource.
StoragePool
A storage pool.
StorageVolume
A storage volume.
File
A filesystem path.
Process
A process.
LogSource
A log source.
ZfsPool
A ZFS pool.
ZfsDataset
A ZFS dataset.
ZfsSnapshot
A ZFS snapshot.
Custom(OperationName)
A namespaced target kind defined by an external engine.