pub struct SchemaId(/* private fields */);Expand description
Stable identity for a versioned operation parameter or result schema.
Implementations
Sourceimpl SchemaId
impl SchemaId
Sourcepub fn new(value: impl Into<String>) -> Result<Self, SchemaIdError>
pub fn new(value: impl Into<String>) -> Result<Self, SchemaIdError>
Creates and validates a schema identity.
Sourcepub fn parameters(
operation: &OperationName,
version: u32,
) -> Result<Self, SchemaIdError>
pub fn parameters( operation: &OperationName, version: u32, ) -> Result<Self, SchemaIdError>
Derives the parameter schema identity for one operation version.
Sourcepub fn result(
operation: &OperationName,
version: u32,
) -> Result<Self, SchemaIdError>
pub fn result( operation: &OperationName, version: u32, ) -> Result<Self, SchemaIdError>
Derives the result schema identity for one operation version.