pub struct TargetRef { /* private fields */ }Expand description
Stable, serializable reference to an operation target.
Implementations
Sourceimpl TargetRef
impl TargetRef
Sourcepub fn new(
kind: TargetKind,
id: impl Into<String>,
) -> Result<Self, TargetRefError>
pub fn new( kind: TargetKind, id: impl Into<String>, ) -> Result<Self, TargetRefError>
Creates a target reference with a validated resource identity.
Sourcepub fn with_host(self, host: impl Into<String>) -> Result<Self, TargetRefError>
pub fn with_host(self, host: impl Into<String>) -> Result<Self, TargetRefError>
Associates the target with an explicit host identity.
Sourcepub fn with_parent(self, parent: TargetRef) -> Result<Self, TargetRefError>
pub fn with_parent(self, parent: TargetRef) -> Result<Self, TargetRefError>
Associates the target with a parent resource.
Sourcepub fn with_revision(
self,
revision: impl Into<String>,
) -> Result<Self, TargetRefError>
pub fn with_revision( self, revision: impl Into<String>, ) -> Result<Self, TargetRefError>
Binds the target to a topology or resource revision.
Sourcepub fn kind(&self) -> &TargetKind
pub fn kind(&self) -> &TargetKind
Returns the target category.